% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RoBMA-reg.R
\name{RoBMA.reg}
\alias{RoBMA.reg}
\title{Estimate a Robust Bayesian Meta-Analysis Meta-Regression}
\usage{
RoBMA.reg(
  formula,
  data,
  test_predictors = TRUE,
  study_names = NULL,
  study_ids = NULL,
  transformation = if (any(colnames(data) != "y")) "fishers_z" else "none",
  prior_scale = if (any(colnames(data) != "y")) "cohens_d" else "none",
  standardize_predictors = TRUE,
  effect_direction = "positive",
  priors = NULL,
  model_type = NULL,
  rescale_priors = 1,
  priors_effect = set_default_priors("effect", rescale = rescale_priors),
  priors_heterogeneity = set_default_priors("heterogeneity", rescale = rescale_priors),
  priors_bias = set_default_priors("bias", rescale = rescale_priors),
  priors_effect_null = set_default_priors("effect", null = TRUE),
  priors_heterogeneity_null = set_default_priors("heterogeneity", null = TRUE),
  priors_bias_null = set_default_priors("bias", null = TRUE),
  priors_hierarchical = set_default_priors("hierarchical"),
  priors_hierarchical_null = set_default_priors("hierarchical", null = TRUE),
  prior_covariates = set_default_priors("covariates", rescale = rescale_priors),
  prior_covariates_null = set_default_priors("covariates", null = TRUE),
  prior_factors = set_default_priors("factors", rescale = rescale_priors),
  prior_factors_null = set_default_priors("factors", null = TRUE),
  algorithm = "bridge",
  chains = 3,
  sample = 5000,
  burnin = 2000,
  adapt = 500,
  thin = 1,
  parallel = FALSE,
  autofit = TRUE,
  autofit_control = set_autofit_control(),
  convergence_checks = set_convergence_checks(),
  save = "all",
  seed = NULL,
  silent = TRUE,
  ...
)
}
\arguments{
\item{formula}{a formula for the meta-regression model}

\item{data}{a data.frame containing the data for the meta-regression. Note that the
column names have to correspond to the effect sizes (\code{d}, \code{logOR}, \code{OR},
\code{r}, \code{z}), a measure of sampling variability (\code{se}, \code{v}, \code{n},
\code{lCI}, \code{uCI}, \code{t}), and the predictors.
See \code{\link[=combine_data]{combine_data()}} for a complete list of reserved names and additional information
about specifying input data.}

\item{test_predictors}{vector of predictor names to test for the presence
of moderation (i.e., assigned both the null and alternative prior distributions).
Defaults to \code{TRUE}, all predictors are tested using the default
prior distributions (i.e., \code{prior_covariates},
\code{prior_covariates_null}, \code{prior_factors}, and
\code{prior_factors_null}). To only estimate
and adjust for the effect of predictors use \code{FALSE}. If
\code{priors} is specified, any settings in \code{test_predictors}
is overridden.}

\item{study_names}{an optional argument with the names of the studies}

\item{study_ids}{an optional argument specifying dependency between the
studies (for using a multilevel model). Defaults to \code{NULL} for
studies being independent.}

\item{transformation}{transformation to be applied to the supplied
effect sizes before fitting the individual models. Defaults to
\code{"fishers_z"}. We highly recommend using \code{"fishers_z"}
transformation since it is the only variance stabilizing measure
and does not bias PET and PEESE style models. The other options are
\code{"cohens_d"}, correlation coefficient \code{"r"} and \code{"logOR"}.
Supplying \code{"none"} will treat the effect sizes as unstandardized and
refrain from any transformations.}

\item{prior_scale}{an effect size scale used to define priors. Defaults to \code{"cohens_d"}.
Other options are \code{"fishers_z"}, correlation coefficient \code{"r"},
and \code{"logOR"}. The prior scale does not need to match the effect sizes measure -
the samples from prior distributions are internally transformed to match the
\code{transformation} of the data. The \code{prior_scale} corresponds to
the effect size scale of default output, but can be changed within the summary function.}

\item{standardize_predictors}{whether continuous predictors should be standardized prior to
estimating the model. Defaults to \code{TRUE}. Continuous predictor standardization is important
for applying the default prior distributions for continuous predictors. Note that the resulting
output corresponds to standardized meta-regression coefficients.}

\item{effect_direction}{the expected direction of the effect. Correctly specifying
the expected direction of the effect is crucial for one-sided selection models,
as they specify cut-offs using one-sided p-values. Defaults to \code{"positive"}
(another option is \code{"negative"}).}

\item{priors}{named list of prior distributions for each predictor
(with names corresponding to the predictors). It allows users to
specify both the null and alternative hypothesis prior distributions
for each predictor by assigning the corresponding element of the named
list with another named list (with \code{"null"} and
\code{"alt"}).
If only one prior is specified for a given parameter, it is
assumed to correspond to the alternative hypotheses and the default null
hypothesis is specified (i.e., \code{prior_covariates_null} or
\code{prior_factors_null}).
If a named list with only one named prior distribution is provided (either
\code{"null"} or \code{"alt"}), only this prior distribution is used and no
default distribution is filled in.
Parameters without specified prior distributions are assumed to be only adjusted
for using the default alternative hypothesis prior distributions (i.e.,
\code{prior_covariates} or \code{prior_factors}).
If \code{priors} is specified, \code{test_predictors} is ignored.}

\item{model_type}{string specifying the RoBMA ensemble. Defaults to \code{NULL}.
The other options are \code{"PSMA"}, \code{"PP"}, and \code{"2w"} which override
settings passed to the \code{priors_effect}, \code{priors_heterogeneity},
\code{priors_effect}, \code{priors_effect_null}, \code{priors_heterogeneity_null},
\code{priors_bias_null}, and \code{priors_effect}. See details for more information
about the different model types.}

\item{rescale_priors}{a re-scaling factor for the prior distributions. The re-scaling
factor allows to adjust the width of all default priors simultaneously. Defaults to \code{1}.}

\item{priors_effect}{list of prior distributions for the effect size (\code{mu})
parameter that will be treated as belonging to the alternative hypothesis. Defaults to
a standard normal distribution
\code{prior(distribution = "normal", parameters = list(mean = 0, sd = 1))}.}

\item{priors_heterogeneity}{list of prior distributions for the heterogeneity \code{tau}
parameter that will be treated as belonging to the alternative hypothesis. Defaults to
\code{prior(distribution = "invgamma", parameters = list(shape = 1, scale = .15))} that
is based on heterogeneities estimates from psychology \insertCite{erp2017estimates}{RoBMA}.}

\item{priors_bias}{list of prior distributions for the publication bias adjustment
component that will be treated as belonging to the alternative hypothesis.
Defaults to \code{list(
prior_weightfunction(distribution = "two.sided", parameters = list(alpha = c(1, 1),
    steps = c(0.05)),             prior_weights = 1/12),
prior_weightfunction(distribution = "two.sided", parameters = list(alpha = c(1, 1, 1),
    steps = c(0.05, 0.10)),       prior_weights = 1/12),
prior_weightfunction(distribution = "one.sided", parameters = list(alpha = c(1, 1),
     steps = c(0.05)),             prior_weights = 1/12),
prior_weightfunction(distribution = "one.sided", parameters = list(alpha = c(1, 1, 1),
     steps = c(0.025, 0.05)),      prior_weights = 1/12),
prior_weightfunction(distribution = "one.sided", parameters = list(alpha = c(1, 1, 1),
     steps = c(0.05, 0.5)),        prior_weights = 1/12),
prior_weightfunction(distribution = "one.sided", parameters = list(alpha = c(1, 1, 1, 1),
     steps = c(0.025, 0.05, 0.5)), prior_weights = 1/12),
prior_PET(distribution   = "Cauchy", parameters = list(0,1), truncation = list(0, Inf),
     prior_weights = 1/4),
prior_PEESE(distribution = "Cauchy", parameters = list(0,5), truncation = list(0, Inf),
     prior_weights = 1/4)
)}, corresponding to the RoBMA-PSMA model introduce by \insertCite{bartos2021no;textual}{RoBMA}.}

\item{priors_effect_null}{list of prior distributions for the effect size (\code{mu})
parameter that will be treated as belonging to the null hypothesis. Defaults to
a point null hypotheses at zero,
\code{prior(distribution = "point", parameters = list(location = 0))}.}

\item{priors_heterogeneity_null}{list of prior distributions for the heterogeneity \code{tau}
parameter that will be treated as belonging to the null hypothesis. Defaults to
a point null hypotheses at zero (a fixed effect meta-analytic models),
\code{prior(distribution = "point", parameters = list(location = 0))}.}

\item{priors_bias_null}{list of prior weight functions for the \code{omega} parameter
that will be treated as belonging to the null hypothesis. Defaults no publication
bias adjustment, \code{prior_none()}.}

\item{priors_hierarchical}{list of prior distributions for the correlation of random effects
(\code{rho}) parameter that will be treated as belonging to the alternative hypothesis. This setting allows
users to fit a hierarchical (three-level) meta-analysis when \code{study_ids} are supplied.
Note that this is an experimental feature and see News for more details. Defaults to a beta distribution
\code{prior(distribution = "beta", parameters = list(alpha = 1, beta = 1))}.}

\item{priors_hierarchical_null}{list of prior distributions for the correlation of random effects
(\code{rho}) parameter that will be treated as belonging to the null hypothesis. Defaults to \code{NULL}.}

\item{prior_covariates}{a prior distributions for the regression parameter
of continuous covariates on the effect size under the alternative hypothesis
(unless set explicitly in \code{priors}). Defaults to a relatively wide normal
distribution \code{prior(distribution = "normal", parameters = list(mean = 0, sd = 0.25))}.}

\item{prior_covariates_null}{a prior distributions for the regression parameter
of continuous covariates on the effect size under the null hypothesis
(unless set explicitly in \code{priors}). Defaults to a no effect
\code{prior("spike",  parameters = list(location = 0))}.}

\item{prior_factors}{a prior distributions for the regression parameter
of categorical covariates on the effect size under the alternative hypothesis
(unless set explicitly in \code{priors}). Defaults to a relatively wide
multivariate normal distribution specifying differences from the mean contrasts
\code{prior_factor("mnormal", parameters = list(mean = 0, sd = 0.25), contrast = "meandif")}.}

\item{prior_factors_null}{a prior distributions for the regression parameter
of categorical covariates on the effect size under the null hypothesis
(unless set explicitly in \code{priors}). Defaults to a no effect
\code{prior("spike",  parameters = list(location = 0))}.}

\item{algorithm}{a string specifying the algorithm used for the model averaging. Defaults to \code{"bridge"}
which results in estimating individual models using JAGS and computing the marginal likelihood using bridge
sampling. An alternative is \code{"ss"} which uses spike and slab like parameterization to approximate the
Bayesian model averaging with a single model. Note that significantly more \code{sample}, \code{burnin}, and
\code{adapt} iterations are needed for the \code{"ss"} algorithm.}

\item{chains}{a number of chains of the MCMC algorithm.}

\item{sample}{a number of sampling iterations of the MCMC algorithm.
Defaults to \code{5000}.}

\item{burnin}{a number of burnin iterations of the MCMC algorithm.
Defaults to \code{2000}.}

\item{adapt}{a number of adaptation iterations of the MCMC algorithm.
Defaults to \code{500}.}

\item{thin}{a thinning of the chains of the MCMC algorithm. Defaults to
\code{1}.}

\item{parallel}{whether the individual models should be fitted in parallel.
Defaults to \code{FALSE}. The implementation is not completely stable
and might cause a connection error.}

\item{autofit}{whether the model should be fitted until the convergence
criteria (specified in \code{autofit_control}) are satisfied. Defaults to
\code{TRUE}.}

\item{autofit_control}{allows to pass autofit control settings with the
\code{\link[=set_autofit_control]{set_autofit_control()}} function. See \code{?set_autofit_control} for
options and default settings.}

\item{convergence_checks}{automatic convergence checks to assess the fitted
models, passed with \code{\link[=set_convergence_checks]{set_convergence_checks()}} function. See
\code{?set_convergence_checks} for options and default settings.}

\item{save}{whether all models posterior distributions should be kept
after obtaining a model-averaged result. Defaults to \code{"all"} which
does not remove anything. Set to \code{"min"} to significantly reduce
the size of final object, however, some model diagnostics and further
manipulation with the object will not be possible.}

\item{seed}{a seed to be set before model fitting, marginal likelihood
computation, and posterior mixing for reproducibility of results. Defaults
to \code{NULL} - no seed is set.}

\item{silent}{whether all print messages regarding the fitting process
should be suppressed. Defaults to \code{TRUE}. Note that \code{parallel = TRUE}
also suppresses all messages.}

\item{...}{additional arguments.}
}
\value{
\code{RoBMA.reg} returns an object of class 'RoBMA.reg'.
}
\description{
\code{RoBMA} is used to estimate a robust Bayesian
meta-regression. The interface allows a complete customization of
the ensemble with different prior (or list of prior) distributions
for each component.
}
\details{
The \href{../doc/MetaRegression.html}{\code{vignette("/MetaRegression", package = "RoBMA")}}
vignette describes how to use \code{\link[=RoBMA.reg]{RoBMA.reg()}} function to fit Bayesian meta-regression ensembles. See
\insertCite{bartos2023robust;textual}{RoBMA} for more details about the methodology and
\code{\link[=RoBMA]{RoBMA()}} for more details about the function options. By default, the function standardizes
continuous predictors. As such, the output should be interpreted as standardized meta-regression
coefficients.

The RoBMA.reg function first generates models from a combination of the
provided priors for each of the model parameters. Then, the individual models
are fitted using \link[runjags]{autorun.jags} function. A marginal likelihood
is computed using \link[bridgesampling]{bridge_sampler} function. The individual
models are then combined into an ensemble using the posterior model probabilities
using \link[BayesTools]{BayesTools} package.

Generic \code{\link[=summary.RoBMA]{summary.RoBMA()}}, \code{\link[=print.RoBMA]{print.RoBMA()}}, and \code{\link[=plot.RoBMA]{plot.RoBMA()}} functions are
provided to facilitate manipulation with the ensemble. A visual check of the
individual model diagnostics can be obtained using the \code{\link[=diagnostics]{diagnostics()}} function.
The fitted model can be further updated or modified by \code{\link[=update.RoBMA]{update.RoBMA()}} function.
Estimated marginal means can be computed by \code{\link[=marginal_summary]{marginal_summary()}} function and
visualized by the \code{\link[=marginal_plot]{marginal_plot()}} function.
}
\examples{
\dontrun{
# using the example data from Andrews et al. (2021) and reproducing the example from
# Bartos et al. (2024) with measure and age covariate.

 # note the the Andrews2021 data.frame columns identify the effect size "r" and
 # the standard error "se" of the effect size that are used to estimate the model
 fit_RoBMA <- RoBMA.reg(~ measure + age, data = Andrews2021, parallel = TRUE, seed = 1)

 # summarize the results
 summary(fit_RoBMA, output_scale = "r")

 # compute effect size estimates for each group
 marginal_summary(fit_RoBMA, output_scale = "r")

 # visualize the effect size estimates for each group
 marginal_plot(fit_RoBMA, parameter = "measure", output_scale = "r", lwd = 2)
}

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[=RoBMA]{RoBMA()}} \code{\link[=summary.RoBMA]{summary.RoBMA()}}, \code{\link[=update.RoBMA]{update.RoBMA()}}, \code{\link[=check_setup.reg]{check_setup.reg()}}
}
